# DTU Wind WAsP QGIS plugin

## Install 

This plugin can be installed using "install from zip file" in the QGIS plugin menu.

### Build zip file

It can be zipped up to a package by running the following command from the directory above this repository.
```bash
zip -r wasp_scripts.zip qgis-wasp-plugin -x "qgis-wasp-plugin/.git/*" -x "qgis-wasp-plugin/processing_provider/create_bb_polygons.py" -x "qgis-wasp-plugin/processing_provider/SRTM_viewfinder.py"
```

## Datasets 

### GWA3 landcover data

The GWA data are based on the ESA-CCI 2015 landcover data with 300 m resolution. The full
file was downloaded from the website:
ftp://geo10.elie.ucl.ac.be/CCI/LandCover/ESACCI-LC-L4-LCCS-Map-300m-P1Y-2015-v2.0.7.zip

```bash
gdal_retile.py -co "COMPRESS=LZW" -ps 1080 1080 -targetDir tiles ESACCI-LC-L4-LCCS-Map-300m-P1Y-2015-v2.0.7.tif
```

Afterwards, the script `create_bb_polygon.py` creates a gpkg that contains the bounding boxes of all the tifs 
created above. These are then used to find intersecting tiles with the user specified polygon. These intersecting
tiles are downloaded to the user and clipped and reprojected to the specified clipping layer of the user.

A cloud optimized geotiff can be created using:
```bash
gdal_translate ESACCI-LC-L4-LCCS-Map-300m-P1Y-2015-v2.0.7.tif esa_cci_2015.tif -of COG  -co COMPRESS=LZW -co NUM_THREADS=16
```

# GWA3 elevation data

The GWA elevation are a combination of the [SRTM GL3 v003](www.doi.org/10.5067/MEaSUREs/SRTM/SRTMGL3.003) and the [Viewfinder](http://viewfinderpanoramas.org/) DEMs. More information about this blending can be found in the [GWA Paper](https://doi.org/10.1175/BAMS-D-21-0075.1). 

All tiles were downloaded and the data was exported to COG for use with this plugin.

# Worldcover data
The worldcover data is hosted on Copernicus servers and follows the same approach for the other landcover sources. 
An example script can be found here: https://esa-worldcover.org/en/data-access
Because the 10 m default resolution is making the whole work flow extremely slow the maps are first downsampled to 100 m resolution (default). A user can specify a resolution up to 50 m, but higher is not possible by design.

# CORINE 2018 Vector land cover data

The landcover data is rather big (8GB) and is in vector format, so it is not trivial to use the tiling approach that we used for the raster sources. A custom python API using geopandas was used to open a subset of the CORINE geopackage file, and clip the necessary parts. 
